/*
 * GUI misc module
 * This module is for generic GUI functions.
 *
 * Copyright INOUE Seiichiro <inoue@ainet.or.jp>, licensed under the GPL.
 */
#ifdef HAVE_CONFIG_H
#include "config.h"
#endif
#include <gnome.h>
#include "diff.h"
#include "gui.h"
#include "misc.h"
#include "guimisc.h"


/**
 * ask_yes_no:
 * Show a modal dialog box that has yes, no, cancel buttons.
 **/
QDialogReply
ask_yes_no(const char *msg)
{
	GnomeMessageBox *mbox;

	mbox = GNOME_MESSAGE_BOX(gnome_message_box_new(msg, GNOME_MESSAGE_BOX_QUESTION,
												   GNOME_STOCK_BUTTON_YES, GNOME_STOCK_BUTTON_NO, GNOME_STOCK_BUTTON_CANCEL,
												   NULL));
	gnome_dialog_set_default(GNOME_DIALOG(mbox), 2);
	gtk_window_set_modal(GTK_WINDOW(mbox), TRUE);
	gtk_window_set_position(GTK_WINDOW(mbox), GTK_WIN_POS_MOUSE);
	
	return gnome_dialog_run_and_close(GNOME_DIALOG(mbox));
}


/**
 * make_statusbar_msg:
 * Using file names and line numbers, make a message for status-bar.
 * Returned buffer should be freed by the caller.
 * If the line number is -1, ignore it.
 **/
char*
make_statusbar_msg(const char *fname1, const char *fname2, int f1n1, int f1n2, int f2n1, int f2n2)
{
	char *msg;

	if (f1n1 == -1)
		msg = g_strdup_printf("%s : %s", fname1, fname2);
	else
		msg = g_strdup_printf("%s [%d - %d] : %s [%d - %d]", fname1, f1n1, f1n2, fname2, f2n1, f2n2);

	return msg;
}
