/*
 * Menu for mergeview module
 *
 * Almost every callback function internally calls the related action routine
 * defined in actions.[ch].
 *
 * Copyright INOUE Seiichiro <inoue@ainet.or.jp>, licensed under the GPL.
 */
#ifdef HAVE_CONFIG_H
#include "config.h"
#endif
#include <gnome.h>
#include "diff.h"
#include "gui.h"
#include "rmenu.h"
#include "actions.h"
#include "mergeview.h"


/* Private function declarations */
static void insert_remove_cb(GtkWidget *w, gpointer data);
static void output_file_cb(GtkWidget *w, gpointer data);

/* Keys for gtk_object_[get|set]_data() */
#define MENUITEM_MERGE_KEY		"m"

/* I'm using the same callback function for multiple menu items.
   So I use object data to identify the selected menu items. */
enum {
	BASE_FILE = 1 << 0,
	OTHER_FILE = 1 << 1,
	INSERT_FILE = 1 << 2,
	REMOVE_FILE = 1 << 3
};

/* The menu definitions */
static GnomeUIInfo merge_action_menu[] = {
#define MENUITEM_MERGE_INSERT_1		0
	{GNOME_APP_UI_ITEM, N_("Insert _first file"), NULL,
	 insert_remove_cb, NULL, NULL,
	 GNOME_APP_PIXMAP_NONE, NULL,
	 0, (GdkModifierType)0, NULL},
#define MENUITEM_MERGE_REMOVE_1		1
	{GNOME_APP_UI_ITEM, N_("Remove f_irst file"), NULL,
	 insert_remove_cb, NULL, NULL,
	 GNOME_APP_PIXMAP_NONE, NULL,
	 0, (GdkModifierType)0, NULL},
#define MENUITEM_MERGE_INSERT_2		2
	{GNOME_APP_UI_ITEM, N_("Insert _second file"), NULL,
	 insert_remove_cb, NULL, NULL,
	 GNOME_APP_PIXMAP_NONE, NULL,
	 0, (GdkModifierType)0, NULL},
#define MENUITEM_MERGE_REMOVE_2		3
	{GNOME_APP_UI_ITEM, N_("Remove s_econd file"), NULL,
	 insert_remove_cb, NULL, NULL,
	 GNOME_APP_PIXMAP_NONE, NULL,
	 0, (GdkModifierType)0, NULL},
	GNOMEUIINFO_SEPARATOR,
	{GNOME_APP_UI_ITEM, N_("_Output file"), NULL,
	 output_file_cb, NULL, NULL,
	 GNOME_APP_PIXMAP_NONE, NULL,
	 0, (GdkModifierType)0, NULL},
	GNOMEUIINFO_END
};


/**
 * merge_rmenu_create:
 * Create right-click menu for the file view, and return it.
 **/
GtkWidget*
merge_rmenu_create(void)
{
	GtkWidget *rmenu;

	rmenu = gnome_popup_menu_new(merge_action_menu);

	/* Set index to menu item, to be used in the callback function */
	gtk_object_set_data(
		GTK_OBJECT(merge_action_menu[MENUITEM_MERGE_INSERT_1].widget),
		MENUITEM_MERGE_KEY,
		GINT_TO_POINTER(BASE_FILE | INSERT_FILE));
	gtk_object_set_data(
		GTK_OBJECT(merge_action_menu[MENUITEM_MERGE_REMOVE_1].widget),
		MENUITEM_MERGE_KEY,
		GINT_TO_POINTER(BASE_FILE | REMOVE_FILE));
	gtk_object_set_data(
		GTK_OBJECT(merge_action_menu[MENUITEM_MERGE_INSERT_2].widget),
		MENUITEM_MERGE_KEY,
		GINT_TO_POINTER(OTHER_FILE | INSERT_FILE));
	gtk_object_set_data(
		GTK_OBJECT(merge_action_menu[MENUITEM_MERGE_REMOVE_2].widget),
		MENUITEM_MERGE_KEY,
		GINT_TO_POINTER(OTHER_FILE | REMOVE_FILE));

	return rmenu;
}


/* ---The followings are private functions--- */
/* XXX */
static void
insert_remove_cb(GtkWidget *w, gpointer data)
{
	GdiffMergeView *mergeview = data;
	int index;
	WhichFile whichfile;
	gboolean to_insert;

	index = GPOINTER_TO_INT(gtk_object_get_data(GTK_OBJECT(w), MENUITEM_MERGE_KEY));
	whichfile = index & BASE_FILE ? FIRST_FILE : SECOND_FILE;
	to_insert = index & INSERT_FILE ? TRUE : FALSE;

	act_merge_insert_remove(GTK_WIDGET(mergeview), whichfile, to_insert);
}

static void
output_file_cb(GtkWidget *w, gpointer data)
{
	GdiffMergeView *mergeview = data;

	act_merge_output_file(GTK_WIDGET(mergeview));
}
