/*
 * GUI searchbar module
 *
 * Copyright INOUE Seiichiro <inoue@ainet.or.jp>, licensed under the GPL.
 */
#ifdef HAVE_CONFIG_H
#include "config.h"
#endif
#include <gnome.h>
#include "diff.h"
#include "gui.h"
#include "gdwin.h"
#include "basepane-widget.h"
#include "dirview.h"
#include "mergeview.h"

/* Keys for gtk_object_[get|set]_data() */
/* Two buttons share the same callback function, so I need to distinguish them. */
#define SEARCH_BUTTON_KEY	"sbk"

/* Private variables */
static GtkWidget *entry;/* to input search string */
static GtkWidget *button2_keep;/* workaround */

/* Private function declarations */
static void search_cb(GtkWidget *widget, gpointer data);
	

/**
 * searchbar_create:
 * Create a search-bar. The instance is stored in gdwin.
 **/
void
searchbar_create(GDiffWindow *gdwin)
{
	GnomeApp *app = gdwin->app;
	GtkWidget *hbox;
	GtkWidget *button;
	GtkWidget *pixmapw;
	GtkTooltips *tooltips;

	hbox = gtk_hbox_new(FALSE, 0);
	gtk_container_set_border_width(GTK_CONTAINER(hbox), 2);

	tooltips = gtk_tooltips_new();

	entry = gtk_entry_new();
	gtk_box_pack_start(GTK_BOX(hbox), entry, TRUE, TRUE, 0);

	button = gtk_button_new();
	gtk_button_set_relief(GTK_BUTTON(button), GTK_RELIEF_NONE);
	gtk_object_set_data(GTK_OBJECT(button),
						SEARCH_BUTTON_KEY, GINT_TO_POINTER(FIRST_FILE));
	gtk_signal_connect(GTK_OBJECT(button), "clicked",
					   GTK_SIGNAL_FUNC(search_cb), gdwin);
	gtk_tooltips_set_tip(tooltips, button, _("Search in first file"), NULL);
	pixmapw = gnome_stock_pixmap_widget(GTK_WIDGET(app), GNOME_STOCK_PIXMAP_SEARCH);
	gtk_container_add(GTK_CONTAINER(button), pixmapw);
	gtk_box_pack_start(GTK_BOX(hbox), button, FALSE, FALSE, 0);

	button = gtk_button_new();
	button2_keep = button;/*XXX*/
	gtk_button_set_relief(GTK_BUTTON(button), GTK_RELIEF_NONE);
	gtk_object_set_data(GTK_OBJECT(button),
						SEARCH_BUTTON_KEY, GINT_TO_POINTER(SECOND_FILE));
	gtk_signal_connect(GTK_OBJECT(button), "clicked",
					   GTK_SIGNAL_FUNC(search_cb), gdwin);
	gtk_tooltips_set_tip(tooltips, button, _("Search in second file"), NULL);
	pixmapw = gnome_stock_pixmap_widget(GTK_WIDGET(app), GNOME_STOCK_PIXMAP_SEARCH);
	gtk_container_add(GTK_CONTAINER(button), pixmapw);
	gtk_box_pack_start(GTK_BOX(hbox), button, FALSE, FALSE, 0);

	gtk_widget_show_all(hbox);

	gnome_app_add_docked(app, hbox, "search box", GNOME_DOCK_ITEM_BEH_NORMAL, GNOME_DOCK_TOP, 1, 2, 0);
	gdwin->searchbar = hbox;
	gdwin->search_entry = entry;
}

/* workaround function
   I have no way to search string in the second file in one-pane mode */
void
searchbar_set_sensitive_button2(gboolean sensitive)
{
	gtk_widget_set_sensitive(button2_keep, sensitive);
}


/* ---The followings are private functions--- */
static void
search_cb(GtkWidget *widget, gpointer data)
{
	GDiffWindow *gdwin = data;
	GtkWidget *view;
	GtkArg arg[1];
	WhichFile whichfile;
	const char *entry_string;
	
	view = gdwin_current_view(gdwin);
	if (view == NULL)
		return;

	whichfile = GPOINTER_TO_INT(gtk_object_get_data(GTK_OBJECT(widget), SEARCH_BUTTON_KEY));
	
	entry_string = gtk_entry_get_text(GTK_ENTRY(entry));
	if (entry_string == NULL || entry_string[0] == '\0')
		return;

	if (GDIFF_IS_DIRVIEW(view)) {
		gdiff_dirview_search_string(GDIFF_DIRVIEW(view), entry_string, whichfile);
	} else {
		GdiffBasePane *basepane = NULL;
		
		if (GDIFF_IS_MERGEVIEW(view))
			arg[0].name = "auxpane";/* twopane-widget */
		else
			arg[0].name = "basepane";
		gtk_object_getv(GTK_OBJECT(view), 1, arg);
		basepane = GDIFF_BASEPANE(GTK_VALUE_OBJECT(arg[0]));
		if (basepane == NULL)
			return;
		gdiff_basepane_search_string(basepane, entry_string, whichfile);
	}
}
