/*
 * Two-pane (file)compare view widget header
 *
 * From a GUI perspective, this widget consists of three components,
 * twopane-widget, overview-widget, and vertical scrollbar.
 * This widget is just a GUI container.
 * Almost every logic is handled by GdiffTwoPane widget.
 *
 * Copyright INOUE Seiichiro <inoue@ainet.or.jp>, licensed under the GPL.
 */
#ifndef __GDIFF_TWOPVIEW_H__
#define __GDIFF_TWOPVIEW_H__

#include <gtk/gtkhbox.h>
#include <gtk/gtkvscrollbar.h>
#include "basepane-widget.h"
#include "gdiffoverview.h"

#ifdef __cplusplus 
extern "C" {
#endif /* __cplusplus */

#define GDIFF_TYPE_TWOPVIEW				(gdiff_twopview_get_type())
#define GDIFF_TWOPVIEW(obj)				GTK_CHECK_CAST(obj, gdiff_twopview_get_type(), GdiffTwopView)
#define GDIFF_TWOPVIEW_CLASS(klass)		GTK_CHECK_CLASS_CAST(klass, gdiff_twopview_get_type(), GdiffTwopViewClass)
#define GDIFF_IS_TWOPVIEW(obj)			GTK_CHECK_TYPE(obj, gdiff_twopview_get_type())
#define GDIFF_IS_TWOPVIEW_CLASS(klass)	(GTK_CHECK_CLASS_TYPE((klass), GDIFF_TYPE_TWOPVIEW))


typedef struct _GdiffTwopView       GdiffTwopView;
typedef struct _GdiffTwopViewClass  GdiffTwopViewClass;

struct _GdiffTwopView {
	GtkHBox hbox;

	/* Child GUI components */
	GdiffBasePane *twopane;/* accessed via arg "basepane" */
	GdiffOverview *overview;
	GtkVScrollbar *vscrollboth;
	GtkWidget *rmenu;

	/* backward pointer for reference */
	GDiffWindow *gdwin;

	/* TRUE if this view is under directory view */
	gboolean is_under_dir;
};

struct _GdiffTwopViewClass {
	GtkHBoxClass parent_class;
};


GtkType gdiff_twopview_get_type(void);
GtkWidget* gdiff_twopview_new(DiffDir *diffdir, DiffFiles *dfiles, gboolean is_under_dir);

/* Macros */
/* I could have these informations in this widget, but I don't.
   Instead, they are implicitly kept in twopane widget.
   I provide interfaces for them by macros. */
#define GDIFF_TWOPVIEW_DIFFDIR(twopview)\
	(GDIFF_BASEPANE(GDIFF_TWOPVIEW(twopview)->twopane)->diffdir)
#define GDIFF_TWOPVIEW_DFILES(twopview)\
	(GDIFF_BASEPANE(GDIFF_TWOPVIEW(twopview)->twopane)->dfiles)
#define GDIFF_TWOPVIEW_FILENAME(twopview, whichfile)\
	(GDIFF_BASEPANE(GDIFF_TWOPVIEW(twopview)->twopane)->filename[whichfile])
#define GDIFF_TWOPVIEW_PREF(twopview)\
	(GDIFF_BASEPANE(GDIFF_TWOPVIEW(twopview)->twopane)->pref)

#ifdef __cplusplus
} 
#endif /* __cplusplus */
 
#endif /* __GDIFF_TWOPVIEW_H__ */
